@@ -1,5 +1,4 @@
 import logging
-import json
 from dataclasses import dataclass, field
 from itertools import compress
 
@@ -11,6 +10,7 @@ from . import preprocessing
 from .pilot import PilotOutput, pilot, adjust_rotation
 from .trace import TraceOutput, trace
 
+
 _feature_prefix = 'feature_'
 _algo_prefix = 'algo_'
 
@@ -38,18 +38,17 @@ class Model:
     trace: TraceOutput = field(init=False)
 
 
-def train_is(metadata: pd.DataFrame, opts: dict) -> Model:
+def train_is(metadata: pd.DataFrame, opts: dict, rotation_adjust=False) -> Model:
     """
     Train Instance Space model.
 
     :param pandas.DataFrame metadata: dataframe where each row corresponds to an instance
     :param dict opts: (nested) dictionary with options
+    :param bool rotation_adjust: attempts to adjust the IS angle (bad instances at 135 degrees) - default False
     :return: model with results for all the steps according to the options passed
     :rtype: Model
     """
     logger = logging.getLogger(__name__)
-    # logger.info(f"Listing options to be used:")
-    # logger.info(json.dumps(opts, indent=4))
 
     data = Data()
     data.instlabels = metadata.index.copy()
@@ -79,8 +78,8 @@ def train_is(metadata: pd.DataFrame, opts: dict) -> Model:
             msg = msg + f"within {np.round(100 * opts['perf']['epsilon'])}% of the best."
     else:
         Yaux = Yraw.fillna(np.inf).values
-        rankPerf = np.sort(Yaux, axis=1)[:, ::-1]
-        rankAlgo = np.argsort(Yaux, axis=1)[:, ::-1]
+        rankPerf = np.sort(Yaux, axis=1)
+        rankAlgo = np.argsort(Yaux, axis=1)
         data.bestPerformace = rankPerf[:, [0]]
         data.P = rankAlgo[:, 0]
         if opts['perf']['AbsPerf']:
@@ -132,8 +131,13 @@ def train_is(metadata: pd.DataFrame, opts: dict) -> Model:
     logger.info("Calling PILOT to find the optimal projection.")
     model.pilot = pilot(data.X, data.Y, featlabels=data.featlabels, **opts['pilot'])
 
-    # model.pilot.Z = adjust_rotation(model.pilot.Z, ~model.data.Ybin.any(axis=1).reshape(-1, 1))
-    # model.pilot.Z = adjust_rotation(model.pilot.Z, ~mode(model.data.Ybin, axis=1)[0])
+    if rotation_adjust:
+        bad_instances = mode(model.data.Ybin, axis=1)[0] == 0
+        if bad_instances.any():
+            logger.info("Adjusting the IS rotation.")
+            model.pilot.Z = adjust_rotation(model.pilot.Z, bad_instances[:, 0])
+        else:
+            logger.info("It is not possible to adjust the IS rotation because there are no bad instances.")
 
     logger.info("Calling TRACE to perform the footprint analysis.")
     model.trace = trace(model.pilot.Z, model.data.Ybin, model.data.P,
